use strict;
use warnings;
package Acme::Coinbase;

# ABSTRACT: Simple Coinbase API Test

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::Coinbase - Simple Coinbase API Test

=head1 VERSION

version 0.007

=head1 SYNOPSIS

Example of a usage goes here, such as...

=head1 DESCRIPTION

What the object does.

=head1 NAME

Acme::Coinbase -- Test coinbase client

=head1 METHODS

=head1 COPYRIGHT

Copyright (c) 2014 Josh Rabinowitz, All Rights Reserved.

=head1 AUTHORS

Josh Rabinowitz

=head1 AUTHOR

joshr <joshr>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by joshr.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
